@@ -150,7 +150,7 @@ class ArtellaMenusManager(menus.MenusManager, object):
                 child_widget.deleteLater()
 
         bug_tracker_action = QAction(parent_menu_bar)
-        bug_tracker_action.setIcon(tpDcc.ResourcesMgr().icon('bug'))
+        bug_tracker_action.setIcon(tpDcc.ResourcesMgr().icon('bug', theme='color'))
         parent_menu_bar.addAction(bug_tracker_action)
         bug_tracker_action.setObjectName(bug_object_action_name)
         bug_tracker_action.triggered.connect(partial(self._launch_tool_by_id, 'artellapipe-tools-bugtracker'))
@@ -190,7 +190,7 @@ class ArtellaMenusManager(menus.MenusManager, object):
             if item_lbl == 'separator':
                 tray_menu.addSeparator()
             else:
-                item_icon = tpDcc.ResourcesMgr().icon(item_icon_name)
+                item_icon = tpDcc.ResourcesMgr().icon(item_icon_name, theme='color')
                 if item_icon and not item_icon.isNull():
                     new_item = QAction(item_icon, item_lbl, tray_menu)
                 else:
