@@ -18,12 +18,12 @@ from functools import partial
 from Qt.QtCore import *
 from Qt.QtWidgets import *
 
-from tpQtLib.core import base
-from tpQtLib.widgets import breadcrumb, stack, splitters, grid
+import tpDcc
+from tpDcc.libs.qt.core import base
+from tpDcc.libs.qt.widgets import breadcrumb, stack, dividers, grid
 
 import artellapipe.register
 from artellapipe.core import defines
-from artellapipe.utils import resource
 from artellapipe.libs.artella.core import artellalib
 
 
@@ -59,7 +59,7 @@ class AssetInfoWidget(base.BaseWidget, object):
         self._asset_icon_frame.setLayout(asset_icon_layout)
         self._asset_icon_lbl = QLabel()
         self._asset_icon_lbl.setAlignment(Qt.AlignCenter)
-        self._asset_icon_lbl.setPixmap(resource.ResourceManager().pixmap('default'))
+        self._asset_icon_lbl.setPixmap(tpDcc.ResourcesMgr().pixmap('default'))
         self._asset_toolbar_layout = QVBoxLayout()
         self._asset_toolbar_layout.setContentsMargins(2, 2, 2, 2)
         self._asset_toolbar_layout.setSpacing(5)
@@ -69,7 +69,7 @@ class AssetInfoWidget(base.BaseWidget, object):
 
         self.main_layout.addWidget(self._title_breadcrumb)
         self.main_layout.addWidget(self._asset_icon_frame)
-        # self.main_layout.addLayout(splitters.SplitterLayout())
+        # self.main_layout.addLayout(dividers.DividerLayout())
 
     def reset(self):
         """
@@ -86,7 +86,7 @@ class AssetInfoWidget(base.BaseWidget, object):
         if not self._asset_widget:
             return
 
-        self._title_breadcrumb.set([self._asset_widget.asset.get_name()])
+        self._title_breadcrumb.set_items([{'text': self._asset_widget.asset.get_name()}])
         thumb_icon = self._asset_widget.get_thumbnail_icon()
         thumb_size = artellapipe.AssetsMgr().config.get('thumb_size')
         self._asset_icon_lbl.setPixmap(
@@ -113,12 +113,12 @@ class AssetInfoWidget(base.BaseWidget, object):
 
         artella_btn = QToolButton()
         artella_btn.setText('Artella')
-        artella_btn.setIcon(resource.ResourceManager().icon('artella'))
+        artella_btn.setIcon(tpDcc.ResourcesMgr().icon('artella'))
         artella_btn.setToolButtonStyle(Qt.ToolButtonTextUnderIcon)
 
         view_locally_btn = QToolButton()
         view_locally_btn.setText('Folder')
-        view_locally_btn.setIcon(resource.ResourceManager().icon('folder'))
+        view_locally_btn.setIcon(tpDcc.ResourcesMgr().icon('folder'))
         view_locally_btn.setToolButtonStyle(Qt.ToolButtonTextUnderIcon)
 
         toolbar_layout.addItem(QSpacerItem(10, 0, QSizePolicy.Expanding, QSizePolicy.Preferred))
@@ -168,8 +168,8 @@ class StatusStack(base.BaseWidget, object):
         buttons_group = QButtonGroup(self)
         buttons_group.setExclusive(True)
 
-        working_icon = resource.ResourceManager().icon('working')
-        published_icon = resource.ResourceManager().icon('box')
+        working_icon = tpDcc.ResourcesMgr().icon('working')
+        published_icon = tpDcc.ResourcesMgr().icon('box')
 
         self._working_btn = QPushButton('Working')
         self._working_btn.setIcon(working_icon)
@@ -234,11 +234,12 @@ class AssetFileButton(base.BaseWidget, object):
 
     checkVersions = Signal(str, object)
 
-    def __init__(self, asset_widget, status, asset_file_type, asset_file_icon, parent=None):
+    def __init__(self, asset_widget, status, asset_file_type, asset_file_type_name, asset_file_icon, parent=None):
 
         self._asset_file_icon = asset_file_icon
         self._status = status
         self._asset_file_type = asset_file_type
+        self._asset_file_type_name = asset_file_type_name or asset_file_type
         self._asset_widget = asset_widget
 
         super(AssetFileButton, self).__init__(parent=parent)
@@ -255,10 +256,10 @@ class AssetFileButton(base.BaseWidget, object):
     def ui(self):
         super(AssetFileButton, self).ui()
 
-        folder_icon = resource.ResourceManager().icon('artella')
+        folder_icon = tpDcc.ResourcesMgr().icon('artella')
 
         self._file_btn = QPushButton()
-        self._file_btn.setText(self._asset_file_type.title())
+        self._file_btn.setText(self._asset_file_type_name)
         self._file_btn.setIcon(self._asset_file_icon)
         self._versions_btn = QPushButton()
         self._versions_btn.setFixedWidth(25)
@@ -286,8 +287,26 @@ class AssetFileButton(base.BaseWidget, object):
 
         file_path = self._get_file_path()
         if not file_path or not os.path.exists(file_path):
-            self._file_btn.setEnabled(False)
-            self._versions_btn.setEnabled(False)
+            self._disable_state()
+            return
+
+        self._enable_state()
+
+    def _enable_state(self):
+        """
+        Internal function that enables the functionality of asset file buttons
+        """
+
+        self._file_btn.setEnabled(True)
+        self._versions_btn.setEnabled(True)
+
+    def _disable_state(self):
+        """
+        Internal function that disables the functionality of asset file buttons
+        """
+
+        self._file_btn.setEnabled(False)
+        self._versions_btn.setEnabled(False)
 
     def _get_file_path(self):
         """
@@ -307,10 +326,10 @@ class AssetFileButton(base.BaseWidget, object):
         if not self._asset_widget:
             return
 
-        if not file_type or file_type not in self._asset_widget.asset.ASSET_FILES:
+        if not file_type or file_type not in self._asset_widget.asset.FILES:
             return
 
-        self._asset_widget.asset.open_file(file_type=self._asset_file_type, status=self._status)
+        return self._asset_widget.asset.open_file(file_type=self._asset_file_type, status=self._status)
 
     def _on_check_working_versions(self, file_type):
         """
@@ -320,7 +339,7 @@ class AssetFileButton(base.BaseWidget, object):
         if not self._asset_widget:
             return
 
-        if not file_type or file_type not in self._asset_widget.asset.ASSET_FILES:
+        if not file_type or file_type not in self._asset_widget.asset.FILES:
             return
 
         file_path = self._get_file_path()
@@ -340,6 +359,9 @@ class AssetVersionsTree(QTreeWidget, object):
 
 
 class WorkingAssetInfo(base.BaseWidget, object):
+
+    STATUS = defines.ArtellaFileStatus.WORKING
+
     def __init__(self, asset_widget, parent=None):
 
         self._asset_widget = asset_widget
@@ -366,9 +388,9 @@ class WorkingAssetInfo(base.BaseWidget, object):
 
         self._buttons_widget = self._create_asset_files_buttons()
 
-        self.main_layout.addLayout(splitters.SplitterLayout())
+        self.main_layout.addLayout(dividers.DividerLayout())
         self.main_layout.addWidget(self._buttons_widget)
-        self.main_layout.addLayout(splitters.SplitterLayout())
+        self.main_layout.addLayout(dividers.DividerLayout())
 
         self._stack = stack.SlidingStackedWidget()
         self._stack.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
@@ -377,12 +399,13 @@ class WorkingAssetInfo(base.BaseWidget, object):
         no_items_widget = QFrame()
         no_items_widget.setFrameShape(QFrame.StyledPanel)
         no_items_widget.setFrameShadow(QFrame.Sunken)
+        no_items_widget.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Expanding)
         no_items_layout = QVBoxLayout()
         no_items_layout.setContentsMargins(0, 0, 0, 0)
         no_items_layout.setSpacing(0)
         no_items_widget.setLayout(no_items_layout)
         no_items_lbl = QLabel()
-        no_items_pixmap = resource.ResourceManager().pixmap('no_asset_selected')
+        no_items_pixmap = tpDcc.ResourcesMgr().pixmap('no_asset_selected')
         no_items_lbl.setPixmap(no_items_pixmap)
         no_items_lbl.setAlignment(Qt.AlignCenter)
         no_items_layout.addItem(QSpacerItem(0, 10, QSizePolicy.Preferred, QSizePolicy.Expanding))
@@ -428,17 +451,25 @@ class WorkingAssetInfo(base.BaseWidget, object):
         file_buttons_widget.resizeColumnsToContents()
         file_buttons_widget.setSelectionMode(QAbstractItemView.NoSelection)
 
-        for file_type in self._asset_widget.asset.ASSET_FILES:
+        files_btn = list()
+        must_file_types = artellapipe.AssetsMgr().must_file_types
+        for file_type in self._asset_widget.asset.FILES:
+            if must_file_types:
+                if file_type not in must_file_types:
+                    continue
+            file_type_name = artellapipe.FilesMgr().get_file_type_name(file_type)
             file_btn = AssetFileButton(
-                self._asset_widget, defines.ArtellaFileStatus.WORKING,
-                file_type, resource.ResourceManager().icon(file_type))
+                self._asset_widget, self.STATUS,
+                file_type, file_type_name, tpDcc.ResourcesMgr().icon(file_type))
+            files_btn.append(file_btn)
             file_btn.checkVersions.connect(self._on_check_versions)
             self._file_buttons[file_type] = file_btn
             row, col = file_buttons_widget.first_empty_cell()
             file_buttons_widget.addWidget(row, col, file_btn)
             file_buttons_widget.resizeRowsToContents()
 
-        file_buttons_widget.setFixedHeight(file_buttons_widget.rowCount() * 26)
+        if files_btn:
+            file_buttons_widget.setFixedHeight(file_buttons_widget.rowCount() * files_btn[0].height() + 10)
 
         return file_buttons_widget
 
@@ -471,17 +502,12 @@ class WorkingAssetInfo(base.BaseWidget, object):
         print(version_info)
 
 
-class PublishedAssetInfo(base.BaseWidget, object):
+class PublishedAssetInfo(WorkingAssetInfo, object):
+
+    STATUS = defines.ArtellaFileStatus.PUBLISHED
+
     def __init__(self, asset_widget, parent=None):
-
-        self._asset_widget = asset_widget
-
-        super(PublishedAssetInfo, self).__init__(parent=parent)
-
-    def ui(self):
-        super(PublishedAssetInfo, self).ui()
-
-        self.main_layout.addWidget(QPushButton('TEST'))
+        super(PublishedAssetInfo, self).__init__(asset_widget=asset_widget, parent=parent)
 
 
 artellapipe.register.register_class('AssetInfo', AssetInfoWidget)
